* Note: this do-file generates all the tables&figures appeared in the paper "Wealthier and Happier? A Cross-sectional Time-series Analysis of China (2003-2013)" by Hania Fei Wu
* The data used are generated by the author from openly accessed CGSS data and yearbook extractions, for details on data generating process, please contact with Hania via email: gintoolwhale@gmail.com 
* Created by Hania Fei Wu
* Last update: May-9-2016

use  cgssep0313CJS16.dta ,clear
mark anlzsp1 if hap!=.&lggrp!=.&lgfmincopcdefl!=.&educ_yr!=.&age!=.&male!=.&ubrr!=.&married!=.&migrant!=.&pty!=.&unemp!=.
mark anlzsp2 if hap!=.&lggrp!=.&prov!=.

*>>>>>>>>>>TABLES<<<<<<<<<<<<<<*

*======Table1. Summary Statistics======*
bys year: sum hap lggrp lgfmincopcdefl educ_yr married migrant pty unemp male ubrr age [aw=weight] if anlzsp1  
sum hap lggrp lgfmincopcdefl educ_yr married migrant pty unemp male ubrr age [aw=weight] if anlzsp1  

*======Table2 (khb estimates). Between individual: family income and hap, w & wo province fixed eff======*
defv provyear =prov*year
defv age2d100 =age^2/100
* C03, fist develop a "full" model including all vars in m1(baseline wo prov dummy control)&m2(w prov dummy controll)
* develop a "full" model as an anchor for other models, here use a random var as the "new" vars, meaning in the presented model (which are all reducde models), this new var will Not be included. 
generate newv =runiform()
foreach yr of numlist 2003 2005 2006 2008 2010 2011 2012 2013 {
* m1: reduced model will only include lgfminc
khb ologit hap lgfmincopcdefl || i.prov newv if anlzsp1==1&year==`yr' [pw=weight], concomitant(educ_yr married migrant pty unemp age age2d100 male ubrr) vce(cl prov) verbose
* m2:reduced model will include both lgfminc and province
khb ologit hap lgfmincopcdefl i.prov || newv if anlzsp1==1&year==`yr' [pw=weight], concomitant(educ_yr married migrant pty unemp age age2d100 male ubrr) vce(cl prov) verbose
}
khb ologit hap lgfmincopcdefl|| i.prov  newv if anlzsp1==1 [pw=weight], concomitant(educ_yr married migrant pty unemp age age2d100 male ubrr) vce(cl provyear) verbose
khb ologit hap lgfmincopcdefl i.prov i.year|| newv if anlzsp1==1 [pw=weight], concomitant(educ_yr married migrant pty unemp age age2d100 male ubrr) vce(cl provyear) verbose

*======Table3: Between province, provincial level, grp & hap, weighted mean & S&W Index======*
* Weighted Mean
foreach yr of numlist 2003 2005 2006 2008 2010 2011 2012 2013 {
reg hapwtmean lggrp [pw=weight] if anlzsp2==1&year==`yr' ,cluster(prov)
}
reg hapwtmean lggrp i.year [pw=weight] if anlzsp2==1,cluster(prov)
defv hdr =prov
recode hdr 31 11 12 32 33 44 37 21 35=1 15 13 23 22 65 14 41 42 46 50 64 63 61 43 51 36 53 54 45 34 62 52=2
reg hapwtmean lggrp i.year [pw=weight] if anlzsp2==1&hdr==1,cluster(prov)
reg hapwtmean lggrp i.year [pw=weight] if anlzsp2==1&hdr==2,cluster(prov)
* S&W indicator
foreach yr of numlist 2003 2005 2006 2008 2010 2011 2012 2013 {
reg hapswwt lggrp [pw=weight] if anlzsp2==1&year==`yr' ,cluster(prov)
}
reg hapswwt lggrp i.year [pw=weight] if anlzsp2==1,cluster(prov)
reg hapswwt lggrp i.year [pw=weight] if anlzsp2==1&hdr==1,cluster(prov)
reg hapswwt lggrp i.year [pw=weight] if anlzsp2==1&hdr==2,cluster(prov)

*======Table4. Difference model, short and long: CGSS2003-2013 or CGSS2005-2013======*
* Weighted Mean:2003-2013
collapse hapwtmean lggrp,by(prov year)
sort prov year
bys prov: gen hapdifs =hapwtmean[_n]-hapwtmean[_n-1] 
bys prov: gen hapdifl =hapwtmean[_N]-hapwtmean[1]
bys prov: gen grpdifs =lggrp[_n]-lggrp[_n-1]
bys prov: replace grpdifs =lggrp[_n]-lggrp[_n-1]
bys prov: gen grpdifl =lggrp[_N]-lggrp[1]

reg hapdifs grpdifs ,cluster (prov)
reg hapdifl grpdifl,cluster (prov)

* S&W index:2003-2013
use  cgssep0313CJS16.dta ,clear
collapse hapswwt lggrp,by(prov year)
sort prov year
bys prov: gen hapdifs =hapswwt[_n]-hapswwt[_n-1] 
bys prov: gen hapdifl =hapswwt[_N]-hapswwt[1]
bys prov: gen grpdifs =lggrp[_n]-lggrp[_n-1] 
bys prov: gen grpdifl =lggrp[_N]-lggrp[1]

reg hapdifs grpdifs ,cluster (prov)
reg hapdifl grpdifl,cluster (prov)

* Weighted Mean:2005-2013
use  cgssep0313CJS16.dta ,clear
drop if year==2003
collapse hapwtmean lggrp,by(prov year)
sort prov year
bys prov: gen hapdifl =hapwtmean[_N]-hapwtmean[1]
bys prov: gen grpdifl =lggrp[_N]-lggrp[1]

reg hapdifl grpdifl,cluster (prov)

* S&W index:2005-2013
use  cgssep0313CJS16.dta ,clear
drop if year==2003
collapse hapswwt lggrp,by(prov year)
sort prov year
bys prov: gen hapdifl =hapswwt[_N]-hapswwt[1]
bys prov: gen grpdifl =lggrp[_N]-lggrp[1]

reg hapdifl grpdifl,cluster (prov)

*>>>>>>>>>>FIGURES<<<<<<<<<<<<<<*
*====== Figure 1. National level, average HAP by Year, WVS & CGSS======*
use  cgssep0313CJS16.dta ,clear
defv wvs =0
append using wvshap9012
defv wvs =1 if wvs==.
bys year: egen satmwvs =mean(sat) if wvs==1
bys year: egen hapmcgss =mean(hap) if wvs==0
twoway (connected satmwvs year,sort yaxis(1) xtitle("Year") ytitle("Average Level of Life Satisfaction"))(connected hapmcgss year,sort yaxis(2) xtitle("Year") ytitle("Average Level of Happiness",axis(2)) msymbol(D)) ,legend(order(1 "Life Satisfaction from WVS" 2 "Happiness from CGSS") bexpand) graphregion(ifcolor(white) fcolor(white))

*======Figure 2: National level, average HAP by Log GDPpc======*
defv ntgdppc =314.43 if year==1990
defv ntgdppc =604.23 if year==1995
defv ntgdppc =1041.64 if year==2001
defv ntgdppc =1273.64 if year==2003
defv ntgdppc =1731.13 if year==2005
defv ntgdppc =2069.34 if year==2006
defv ntgdppc =2651.26 if year==2007
defv ntgdppc =3413.59 if year==2008
defv ntgdppc =4433.36 if year==2010
defv ntgdppc =5447.34 if year==2011
defv ntgdppc =6091.01 if year==2012
defv ntgdppc =6807.43 if year==2013
defv lgntgdp =ln(ntgdppc)
twoway (connected lgntgdp year if wvs==0,sort yaxis(1) ytitle("Log(GDP per capita/USD)") xtitle("Year"))(connected hapmcgss year if wvs==0,sort yaxis(2) ytitle("Average Level of Happiness",axis(2))xtitle("Year") msymbol(D)), legend(order(1 "Log(GDP per capita/USD)" 2 "Happiness from CGSS") bexpand) graphregion(ifcolor(white) fcolor(white))

*======Figure 3: Provincial level, scatter&fitline, by svy year ======*
use   cgssep0313CJS16.dta ,clear
twoway (scatter hapwtmean lggrp if year==2003,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2003,sort ylabel(3 (.5) 4.5) title("CGSS2003",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov03,replace)
twoway (scatter hapwtmean lggrp if year==2005,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2005,sort ylabel(3 (.5) 4.5) title("CGSS2005",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov05,replace)
twoway (scatter hapwtmean lggrp if year==2006,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2006,sort ylabel(3 (.5) 4.5) title("CGSS2006",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov06,replace)
twoway (scatter hapwtmean lggrp if year==2008,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2008,sort ylabel(3 (.5) 4.5) title("CGSS2008",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov08,replace)
twoway (scatter hapwtmean lggrp if year==2010,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2010,sort ylabel(3 (.5) 4.5) title("CGSS2010",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov10,replace)
twoway (scatter hapwtmean lggrp if year==2011,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2011,sort ylabel(3 (.5) 4.5) title("CGSS2011",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov11,replace)
twoway (scatter hapwtmean lggrp if year==2012,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2012,sort ylabel(3 (.5) 4.5) title("CGSS2012",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov12,replace)
twoway (scatter hapwtmean lggrp if year==2013,sort msize(vsmall) mcolor(gs12))(lfit hapwtmean lggrp if year==2013,sort ylabel(3 (.5) 4.5) title("CGSS2013",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) name(prov13,replace)
graph combine prov03 prov05 prov06 prov08 prov10 prov11 prov12 prov13

defv provcn =prov
lab def provcn 11 "" 12"" 13"ӱ" 14"ɽ" 15"ɹ" 21"" 22"" 23"" 31"Ϻ" 32"" 33"㽭" 34"" 35"" 36"" 37"ɽ" 41"" 42"" 43"" 44"㶫" 45"" 46"" 50"" 51"Ĵ" 52"" 53"" 54"" 61"" 62"" 63"ຣ" 64"" 65"½"
lab val provcn provcn
twoway (scatter hapwtmean lggrp if year==2010,sort msize(vsmall) mcolor(gs12)mlabel (provcn))(lfit hapwtmean lggrp if year==2010,sort ylabel(3 (.5) 4.5) title("CGSS2010",color(black))xtitle("Log(˾ֵ)") ytitle("ʡҸоֵ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) 

*======Figure 4: Prov level, c03-13, long diff ======*
use   cgssep0313CJS16.dta ,clear
collapse hapwtmean lggrp,by(prov year)
sort prov year
bys prov: gen hapdifl =hapwtmean[_N]-hapwtmean[1]
bys prov: gen grpdifl =lggrp[_N]-lggrp[1]
reg hapdifl grpdifl,cluster (prov)

defv provcn =prov
lab def provcn 11 "" 12"" 13"ӱ" 14"ɽ" 15"ɹ" 21"" 22"" 23"" 31"Ϻ" 32"" 33"㽭" 34"" 35"" 36"" 37"ɽ" 41"" 42"" 43"" 44"㶫" 45"" 46"" 50"" 51"Ĵ" 52"" 53"" 54"" 61"" 62"" 63"ຣ" 64"" 65"½"
lab val provcn provcn
drop if prov==54
twoway (scatter hapdifl grpdifl,sort msize(vsmall) mcolor(gs12)mlabel (provcn))(lfit hapdifl grpdifl,sort title("CGSS2003-2013",color(black)) xtitle("Log (GRPpc)ĳڲ        (y=.403*x+.103,insig)") ytitle("ʡҸоֵĳڲ")lcolor(black) graphregion(ifcolor(white) fcolor(white))),legend(off) 

clear
